Authors — SQLObject 3.9.1 documentation

# Authors

SQLObject was originally written by Ian Bicking <ianb@colorstudy.com>.

Contributions have been made by:

- Frank Barknecht <fbar at footils.org>

- Bud P. Bruegger <bug at sistema.it>

- David M. Cook <dave at davidcook.org>

- Luke Opperman <luke at metathusalan.com>

- James Ralston <jralston at hotmail.com>

- Sidnei da Silva <sidnei at awkly.org>

- Brad Bollenbach <brad at bbnet.ca>

- Daniel Savard, Xsoli Inc <sqlobject at xsoli.com>

- alexander smishlajev <alex at ank-sia.com>

- Yaroslav Samchuk <yarcat at ank-sia.com>

- Runar Petursson <grunar at gmail.com>

- J Paulo Fernandes Farias <jpaulofarias at gmail.com>

- Shahms King <shahms at shahms.com>

- David Turner, The Open Planning Project

- Dan Pascu <dan at ag-projects.com>

- Diez B. Roggisch <deets at web.de>

- Christopher Singley <csingley at gmail.com>

- Daniel Fetchinson <fetchinson at googlemail.com>

- Neil Muller <drnlmuller+sqlobject at gmail.com>

- Petr Jakes <petr.jakes at tpc.cz>

- Ken Lalonde

- Andrew Ziem <ahz001 at gmail.com>

- Andrew Trusty <atrusty at gatech.edu>

- Ian Cordasco <graffatcolmingov at gmail.com>

- Lukasz Dobrzanski <lukasz.m.dobrzanski at gmail.com>

- Gregor Horvath <gh at gregor-horvath.com>

- Nathan Edwards <nje5 at georgetown.edu>

- Lutz Steinborn <l.steinborn at 4c-gmbh.de>

- Shailesh Mungikar <shailesh.mungikar at druva.com>

- Michael S. Root <miker at tippett.com>

- Scott Stahl <sstahl at onshift.com>

- Markus Elfring <elfring at users.sourceforge.net>

- Oleg Broytman <phd@phdru.name>